# Methods

## Mutant selection via molecular modeling in Foldit 

The crystal structure of recombinant BglB in complex with the substrate analog 2-deoxy-2-fluoro-α-D-glucopyranose was used to identify the substrate binding pocket and the catalytic residues, and a macromolecular model of BglB was created using Rosetta. Functional constraints were used to define catalytic distances, angles, and dihedrals among 4-nitrophenyl-β-D-glucoside, E164, E353, and Y295. The structure was then loaded into Foldit, a graphical user interface to Rosetta. Point mutations to the protein were modeled, and a subset were chosen by students learning about molecular modeling. Generally, the designs had energies no more than 5 Rosetta energy units higher than the native structure.

## Molecular cloning and mutagenesis 

A gene coding for BglB was codon-optimized for *Escherichia coli* and synthesized as linear dsDNA (Life Technologies). The construct was cloned into a pET29b+ vector using Gibson assembly using a commercial reagent mixture (NEB) and verified by Sanger sequencing (Genscript). Kunkel mutagenesis was used to generate designed variants of BglB via an automated cloud laboratory (Transcriptic). 

## Protein production and purification 

Sequence-verified constructs were transformed into *Escherichia coli* BL21(DE3). Single colonies were used to inoculate 5 mL TB in 50 mL Falcon tubes. After incubation at 37 C with shaking at 300 RPM for 24 hours, cells were pelleted and media replaced with 5 mL TB containing 1 mM IPTG. After incubation at 18 C with shaking at 300 RPM for 24 hours, cells were pelleted and lysed with BugBuster (Novogen). 

His-tagged BglB proteins were purified via immobilized metal ion affinity chromatography using 50 µL bed volume of Ni-NTA resin (Thermo) and eluted in 300 µL assay buffer (50 mM HEPES, 150 mM sodium chloride, 25 mM EDTA, pH 7.50). Protein expression was assessed using SDS-PAGE (4-12% gradient gels from Life Technologies). 

## Thermal stability assay and data analysis 

Triplicate aliquots of mutant proteins in assay buffer at concentrations ranging from 0.01 to 0.3 mg/mL (10x diluted from eluate) were incubated at 8 temperatures in evenly-spaced increments between at 30 C and 50 C for 30 minutes in a thermal cycler (BioRad). After incubation, 100 mM pNPG in assay buffer was added, and the rate of pNP production at each temperature was determined by linear fit to data taken at 1 min intervals over 1 hour.  

For each BglB variant, triplicate rates at 8 temperatures were normalized to the [0,1] interval and fit to the logistic equation using least squares (SciPy) to determine the parameters Tm (midpoint) and k (kurtosis).

## Computational modeling and machine learning 

One hundred molecular models of each mutant enzyme were generated using the Rosetta Molecular Modeling Suite by Monte Carlo optimization of total system energy and the lowest 10 of total system energy were selected for feature generation. A total of 50 features were calculated for each protein model [which ones?]. 

The features were used to train a SVM classifier. We assessed model performance using 10-fold cross-validation. First we performed 10-fold cross-validation (CV) and evaluated the predicted performance on the left-out samples (generalization error) at each of the 10 runs. Then we repeated this procedure 1,000 times to randomize the sample distribution among the folds. That way, we reduce the effect of any bias for evaluating left-out prediction performance. More information about the optimization and statistical procedure followed is available [Supp].